]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - client.h
moved EF_MUZZLEFLASH checking to CL_MoveLerpEntityStates to make muzzleflashes reliab...
[xonotic/darkplaces.git] / client.h
index f6772bd20f4b250e91d3b306950e340a574d09ea..1a6ac795a6668ca9818f33ce8f75ad338e45d1f9 100644 (file)
--- a/client.h
+++ b/client.h
@@ -159,9 +159,16 @@ typedef struct dlight_s
        // brightness (not really radius anymore)
        // (worldlight: saved to .rtlights file)
        vec_t radius;
// drop radius this much each second
        // (dlight only)
        vec_t decay;
+       // intensity value which is dropped over time
+       // (dlight only)
+       vec_t intensity;
+       // initial values for intensity to modify
+       // (dlight only)
+       vec_t initialradius;
+       vec3_t initialcolor;
        // light style which controls intensity of this light
        // (worldlight: saved to .rtlights file)
        int style;
@@ -159,9 +159,16 @@ typedef struct dlight_s
        // (worldlight: saved to .rtlights file)
        vec_t radius;
-       // drop radius this much each second
+       // drop intensity this much each second
        // (dlight only)
        vec_t decay;